@@ -27,6 +27,15 @@ create_default_conda_env_if_absent <- function(
   }
 }
 
+create_python_env <- function(model_path,
+                              dependencies,
+                              build_dependencies = list("pip", "setuptools", "wheel")) {
+  python_env_file_name <- "python_env.yaml"
+  deps <- list(build_dependencies = build_dependencies, dependencies = dependencies)
+  write_yaml(deps, file.path(model_path, python_env_file_name))
+  python_env_file_name
+}
+
 assert_pkg_installed <- function(pkg) {
   if (!requireNamespace(pkg, quietly = TRUE)) {
     stop(sprintf("'%s' package must be installed!", pkg))
